@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hackage-security
 version: 0.5.1.0
-id: hackage-security-0.5.1.0-789682785eec4d33c6eff3b78856de3e
-key: hacka_Hh862TjGlKP8cbomHbkP91
+id: hackage-security-0.5.1.0-22f683796618c60d1a5549be3dedf72e
+key: hacka_6y1IYsfWZY8AD1ZfcKsXrP
 license: BSD3
 copyright: Copyright 2015 Well-Typed LLP
 maintainer: edsko@well-typed.com
@@ -61,7 +61,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/hackage-security-0.5.1.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/hackage-security-0.5.1.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/hackage-security-0.5.1.0
-hs-libraries: HShackage-security-0.5.1.0-Hh862TjGlKP8cbomHbkP91
+hs-libraries: HShackage-security-0.5.1.0-6y1IYsfWZY8AD1ZfcKsXrP
 depends:
     Cabal-1.22.5.0-9b2e7feff1fc55070a0a783f283ee9b6
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
@@ -69,15 +69,15 @@ depends:
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cryptohash-sha256-0.11.7.2-ac918cf6abc3ea9a8740c9d302c59b54
+    cryptohash-sha256-0.11.100.0-8fd5cf9cac46ee70000eaa1d709e6e66
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     ed25519-0.0.5.0-ac82093bde15ea4a6d36ab3500bf2ce3
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    network-uri-2.6.1.0-0e39aca8530572505c01ef548c540bd6
-    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
+    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
     pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
     tar-0.5.0.3-0a1915ca475d218d70c2c2cc2299db4e
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
